#!/bin/bash -e
SCRIPTNAME=$(basename $0)
DIRNAME=$(dirname $0)
ORIG_ARGS=("$@")

function update_to_current_version {
    echo "=== Checking for jwt-auth-userinfo script updates... ==="
    TMPD=$(mktemp -d)
    TMP_ARCHIVE="${TMPD}/jwt-auth-userinfo-install-${STAGE}-${REGION}.tgz"
    # TODO: Use proper url and users
    ARCHIVE_URL="${ARCHIVE_URL:-https://artifactory.abas.sh/artifactory/abas.maven-public/jwt-auth-userinfo-installer/jwt-auth-userinfo-install-${STAGE}-${REGION}.tgz}"
    wget -q -O $TMP_ARCHIVE $ARCHIVE_URL
    REMOTE_VERSION=$(tar xOf "$TMP_ARCHIVE" VERSION | head -2 | tail -1)
    LOCAL_VERSION=$(cat VERSION | head -2 | tail -1)
    if [ "$LOCAL_VERSION" -lt "$REMOTE_VERSION" ] ; then
        echo "Your installation of jwt-auth-userinfo scripts ($LOCAL_VERSION) is outdated. Version $REMOTE_VERSION is available."
        mkdir -p $PWD/backup $TMPD/backup
        mv $PWD/jwt-auth-userinfo-scripts-backup*.tgz $PWD/backup 2>/dev/null || true
        BACKUP_FILE="backup/jwt-auth-userinfo-scripts-backup-$(date -u "+%Y%m%d-%H%M%S").tgz"
        echo "Creating backup..."
        tar \
            --exclude='./jwt-auth-userinfo-scripts-backup-*.tgz' \
            --exclude='./logs' \
            --exclude='./backup' \
            -czf "$TMPD/$BACKUP_FILE" .
        mv $TMPD/$BACKUP_FILE $PWD/$BACKUP_FILE
        echo "updating..."

        tar -C "$TMPD" -xzf "$TMP_ARCHIVE"
        if [ -x "$TMPD/abas_pre_update.sh" ] ; then
            # in case we need to do something before we override the installation directory with the contents of the archive
            "$TMPD/abas_pre_update.sh" "$PWD" "$TMPD"
        fi

        mkdir -p "${PWD}/logs/state"
        local old_version="$(cat $PWD/VERSION | tr '\n' ' ')"
        local new_version="$(cat $TMPD/VERSION | tr '\n' ' ')"
        echo "{ \"message\": \"update started\", \"old_version\": \"$old_version\", \"new_version\": \"$new_version\" }" >> "${PWD}/logs/state/update.log"

        tar xzf "$TMP_ARCHIVE"
        if [ -x "$PWD/abas_post_update.sh" ] ; then
            "$PWD/abas_post_update.sh" "$PWD"
        fi

        rm -rf "$TMPD"
        echo "=== Done. ==="

        exec "$0" "${ORIG_ARGS[@]}"
    else
        echo "Skipping jwt-auth-userinfo script update. They are up-to-date."
        echo "=== Done. ==="
    fi
}

#Default values, can be overwritten in jwt-auth-userinfo.config
export ABAS_DOCKER_REGISTRY_NAME=docker.registry.abas.sh


if test -f ${DIRNAME}/jwt-auth-userinfo.config ; then
    echo "Loading configuration from ${DIRNAME}/jwt-auth-userinfo.config"
    . ${DIRNAME}/jwt-auth-userinfo.config
fi

update_to_current_version

mkdir -p ${DIRNAME}/logs/jwt-auth-userinfo

docker-compose -f ${DIRNAME}/docker-compose.yml pull
docker-compose -f ${DIRNAME}/docker-compose.yml up -d